from datetime import datetime


def current_datetime_after_given_iso_string(value: str) -> bool:
    today = datetime.today().now()
    parsed = datetime.fromisoformat(value)
    return today > parsed


def current_datetime_before_given_iso_string(value: str) -> bool:
    today = datetime.today().now()
    parsed = datetime.fromisoformat(value)
    return today < parsed



import pytest
from fsd_utils.simple_utils.data_utils import get_remote_data_as_json
from requests.exceptions import HTTPError


class TestDataUtils:
    def test_get_remote_data_json(self, flask_test_client):
        postcode = "SW1P 4DF"
        result = get_remote_data_as_json(
            f"https://postcodes.io/postcodes/{postcode}"
        )
        assert postcode == result["result"]["postcode"]

    def test_get_remote_data_json_404(self, flask_test_client):
        with pytest.raises(HTTPError):
            get_remote_data_as_json("https://postcodes.io/postcodes/QQ11QQ")



from fsd_utils.config.commonconfig import CommonConfig


def test_get_default_round_id_before_w3(mocker):
    mocker.patch(
        "fsd_utils.config.commonconfig.get_remote_data_as_json",
        return_value={"opens": "2029-01-01"},
    )
    default_round_id = CommonConfig.get_default_round_id()
    assert (
        CommonConfig.COF_ROUND_2_ID == default_round_id
    ), "Should be before W3 launch date"


def test_get_default_round_id_after_w3(mocker):
    mocker.patch(
        "fsd_utils.config.commonconfig.get_remote_data_as_json",
        return_value={"opens": "2023-01-01"},
    )
    default_round_id = CommonConfig.get_default_round_id()
    assert (
        CommonConfig.COF_ROUND_2_W3_ID == default_round_id
    ), "Should be after W3 launch date"
